diff mbox

[edk2,03/11] OvmfPkg/PlatformBootManagerLib: relax device class requirement for ConOut

Message ID 20160819124932.29711-4-lersek@redhat.com
State New
Headers show

Commit Message

Laszlo Ersek Aug. 19, 2016, 12:49 p.m. UTC
This will add virtio-gpu-pci devices to ConOut automatically.

For further benefit, the change also allows OVMF to use the legacy-free /
secondary VGA adapter (added in QEMU commit 63e3e24d, "vga: add secondary
stdvga variant") as console.

ArmVirtPkg's PlatformBootManagerLib already filters with IS_PCI_DISPLAY();
see IsPciDisplay().

Cc: Ard Biesheuvel <ard.biesheuvel@linaro.org>
Cc: Jordan Justen <jordan.l.justen@intel.com>
Ref: https://tianocore.acgmultimedia.com/show_bug.cgi?id=66
Originally-suggested-by: Gerd Hoffmann <kraxel@redhat.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Laszlo Ersek <lersek@redhat.com>

---
 OvmfPkg/Library/PlatformBootManagerLib/BdsPlatform.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

-- 
2.9.2


_______________________________________________
edk2-devel mailing list
edk2-devel@lists.01.org
https://lists.01.org/mailman/listinfo/edk2-devel
diff mbox

Patch

diff --git a/OvmfPkg/Library/PlatformBootManagerLib/BdsPlatform.c b/OvmfPkg/Library/PlatformBootManagerLib/BdsPlatform.c
index 351fbc1e86c7..87412598f51b 100644
--- a/OvmfPkg/Library/PlatformBootManagerLib/BdsPlatform.c
+++ b/OvmfPkg/Library/PlatformBootManagerLib/BdsPlatform.c
@@ -615,13 +615,13 @@  GetGopDevicePath (
   }
 
   return EFI_SUCCESS;
 }
 
 EFI_STATUS
-PreparePciVgaDevicePath (
+PreparePciDisplayDevicePath (
   IN EFI_HANDLE                DeviceHandle
   )
 /*++
 
 Routine Description:
 
@@ -865,20 +865,20 @@  DetectAndPreparePlatformPciDevicePath (
       PreparePciSerialDevicePath (Handle);
       return EFI_SUCCESS;
     }
   }
 
   //
   // Here we decide which VGA device to enable in PCI bus
   //
-  if (IS_PCI_VGA (Pci)) {
+  if (IS_PCI_DISPLAY (Pci)) {
     //
     // Add them to ConOut.
     //
-    DEBUG ((EFI_D_INFO, "Found PCI VGA device\n"));
-    PreparePciVgaDevicePath (Handle);
+    DEBUG ((EFI_D_INFO, "Found PCI display device\n"));
+    PreparePciDisplayDevicePath (Handle);
     return EFI_SUCCESS;
   }
 
@@ -865,20 +865,20 @@  DetectAndPreparePlatformPciDevicePath (
 
   //
-  // Here we decide which VGA device to enable in PCI bus
+  // Here we decide which display device to enable in PCI bus
   //
   return Status;
 }